@@ -4,14 +4,24 @@ import argparse, re
 import sys
 
 from mtools.util.logline import LogLine
+from mtools.util.cmdlinetool import LogFileTool
 from mtools.mlogfilter.filters import *
 
 
 
-class MongoLogFilter(object):
+class MLogFilterTool(LogFileTool):
+
     def __init__(self):
+        LogFileTool.__init__(self, multiple_logfiles=False, stdin_allowed=True)
+        
         self.filters = [] 
 
+        self.argparser.description = 'mongod/mongos log file parser. Use parameters to enable filters. A line only gets printed if it passes all enabled filters.'
+        self.argparser.add_argument('--verbose', action='store_true', help='outputs information about the parser and arguments.')
+        self.argparser.add_argument('--shorten', action='store', type=int, default=False, nargs='?', metavar='LENGTH', help='shortens long lines by cutting characters out of the middle until the length is <= LENGTH (default 200)')
+        self.argparser.add_argument('--exclude', action='store_true', default=False, help='if set, excludes the matching lines rather than includes them.')
+
+
     def addFilter(self, filterClass):
         """ adds a filter class to the parser. """
         if not filterClass in self.filters:
@@ -24,38 +34,27 @@ class MongoLogFilter(object):
         else:
             return arr
 
+    
     def _outputLine(self, line, length=None):
         if length:
             if len(line) > length:
                 line = line[:length/2-2] + '...' + line[-length/2:]
         print line
 
-    def parse(self):
+    
+    def run(self):
         """ parses the logfile and asks each filter if it accepts the line.
             it will only be printed if all filters accept the line.
         """
 
-        # create parser object
-        parser = argparse.ArgumentParser(description='mongod/mongos log file parser. Use parameters to enable filters. A line only gets printed if it passes all enabled filters.')
-        
-        # only create default argument if not using stdin
-        if sys.stdin.isatty():
-            parser.add_argument('logfile', action='store', help='logfile to parse.')
-        
-        parser.add_argument('--verbose', action='store_true', help='outputs information about the parser and arguments.')
-        parser.add_argument('--shorten', action='store', type=int, default=False, nargs='?', metavar='LENGTH', help='shortens long lines by cutting characters out of the middle until the length is <= LENGTH (default 200)')
-        parser.add_argument('--exclude', action='store_true', default=False, help='if set, excludes the matching lines rather than includes them.')
-
-        # add arguments from filter classes
+        # add arguments from filter classes before calling superclass run
         for f in self.filters:
             for fa in f.filterArgs:
-                parser.add_argument(fa[0], **fa[1])
+                self.argparser.add_argument(fa[0], **fa[1])
 
-        self.args = vars(parser.parse_args())
+        # now parse arguments and post-process
+        LogFileTool.run(self)
         self.args = dict((k, self._arrayToString(self.args[k])) for k in self.args)
-        
-        # if self.args['verbose']:
-        #     print self.args
 
         # create filter objects from classes and pass args
         self.filters = [f(self.args) for f in self.filters]
@@ -63,11 +62,9 @@ class MongoLogFilter(object):
         # remove non-active filter objects
         self.filters = [f for f in self.filters if f.active]
 
-        # open logfile
-        if sys.stdin.isatty():
-            logfile = open(self.args['logfile'], 'r')
-        else:
-            logfile = sys.stdin
+        # call setup for each active filter
+        for f in self.filters:
+            f.setup()
 
         if self.args['shorten'] != False:
             if self.args['shorten'] == None:
@@ -79,7 +76,11 @@ class MongoLogFilter(object):
                 print "mlogfilter> %8s: %s" % (a, self.args[a])
 
         # go through each line and ask each filter if it accepts
-        for line in logfile:
+        if not 'logfile' in self.args or not self.args['logfile']:
+            exit()
+
+
+        for line in self.args['logfile']:
             logline = LogLine(line)
 
             if self.args['exclude']:
@@ -92,27 +93,26 @@ class MongoLogFilter(object):
                 if all([f.accept(logline) for f in self.filters]):
                     self._outputLine(logline.line_str, self.args['shorten'])
 
-                # if at least one filter refuses to accept remaining lines, stop
+                # if at least one filter refuses to accept any remaining lines, stop
                 if any([f.skipRemaining() for f in self.filters]):
-                    # if called from shell, break
+                    # if input is not stdin
                     if sys.stdin.isatty():
                         break
 
 
 if __name__ == '__main__':
 
-    # create MongoLogParser instance
-    mlogfilter = MongoLogFilter()
+    tool = MLogFilterTool()
 
     # add filters
-    mlogfilter.addFilter(LogLineFilter)
-    mlogfilter.addFilter(SlowFilter)
-    mlogfilter.addFilter(WordFilter)
-    mlogfilter.addFilter(TableScanFilter)
-    mlogfilter.addFilter(DateTimeFilter)
+    tool.addFilter(LogLineFilter)
+    tool.addFilter(SlowFilter)
+    tool.addFilter(FastFilter)
+    tool.addFilter(WordFilter)
+    tool.addFilter(TableScanFilter)
+    tool.addFilter(DateTimeFilter)
     
-    # start parsing
-    mlogfilter.parse()
+    tool.run()
 
 
 
